@@ -1,4 +1,4 @@
-__all__ = ('UploadFilePoint', 'UserFileObjectPoint')
+__all__ = ('UploadFilePoint', 'UserFileObjectPoint', 'UserFilePoint')
 
 from django.core.validators import RegexValidator
 
@@ -37,12 +37,12 @@ class UserFileObjectPoint(RetrievePointMixin, ContractObjectPoint):
 
 
 class UploadFilePoint(UploadFilePointMixin, ResponseMixin, ContractPoint):
-    _cache_enabled = False
     _point_id = UploadFileID()
     _response_contract = UploadFileResponseContract
     _read_contract = None
 
 
 class UserFilePoint(ListPointMixin, ContractPoint):
+    _cache_enabled = False
     _point_id = UserFileID()
     _read_contract = UserFileReadContract
